@@ -27,7 +27,7 @@ class Entry : public QObject
     Q_PROPERTY(QDateTime updated READ updated CONSTANT)
     Q_PROPERTY(QString link READ link CONSTANT)
     Q_PROPERTY(QString baseUrl READ baseUrl CONSTANT)
-    Q_PROPERTY(bool read READ read WRITE setRead NOTIFY readChanged);
+    Q_PROPERTY(bool read READ read WRITE setRead NOTIFY readChanged)
 
 public:
     Entry(Feed *feed, int index);
@@ -42,6 +42,8 @@ public:
     QString link() const;
     bool read() const;
 
+    Q_INVOKABLE void openLink(const QString &link);
+
     QString baseUrl() const;
 
     void setRead(bool read);
